CartesianChartPoint<D> class

This class has the properties of CartesianChartPoint.

Chart point is a class that is used to store the current x and y values from the data source. Contains x and y coordinates which are converted from the x and y values.

Inheritance

Constructors

CartesianChartPoint({D? x, num? y, num? xValue, num? high, num? low, num? open, num? close, num? volume, num? maximum, num? minimum, num? upperQuartile, num? lowerQuartile, num? median, num? mean, List<num>? outliers, num? bubbleSize, num? cumulative})
Creating an argument constructor of CartesianChartPoint class.

Properties

bubbleSize ↔ num?
Bubble size value of the point.
getter/setter pair
close ↔ num?
Close value of the point.
getter/setter pair
color ↔ Color?
Color of the point.
getter/setter pairinherited
cumulative ↔ num?
Cumulative value of the point.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
high ↔ num?
High value of the point.
getter/setter pair
isVisible ↔ bool
To get the visibility of chart point.
getter/setter pairinherited
low ↔ num?
Low value of the point.
getter/setter pair
lowerQuartile ↔ num?
Lower quartile value of the point.
getter/setter pair
maximum ↔ num?
Maximum value of the point.
getter/setter pair
mean ↔ num?
Mean value of the point.
getter/setter pair
median ↔ num?
Median value of the point.
getter/setter pair
minimum ↔ num?
Minimum value of the point.
getter/setter pair
open ↔ num?
Open value of the point.
getter/setter pair
outliers ↔ List<num>?
Outliers value of the point.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upperQuartile ↔ num?
Upper quartile value of the point.
getter/setter pair
volume ↔ num?
Volume value of the point.
getter/setter pair
x ↔ D?
Raw x value of the point.
getter/setter pairinherited
xValue ↔ num?
X value of chart point.
getter/setter pair
y ↔ num?
Y value of the point.
getter/setter pairinherited

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](ChartDataPointType pointType) → dynamic
override
operator []=(ChartDataPointType pointType, dynamic value) → void
override