CartesianLegendItem class

Represents a cartesian legend item in legends.

Constructors

CartesianLegendItem({required String text, required ShapeMarkerType iconType, required Color iconColor, required double? iconBorderWidth, required int seriesIndex, Color? iconBorderColor, Shader? shader, ImageProvider<Object>? imageProvider, ShapeMarkerType? overlayMarkerType, bool isToggled = false, LegendItemTapCallback? onTap, ItemRenderCallback? onRender, ChartSeriesRenderer? series, int pointIndex = -1})

Properties

degree → double?
Specifies the degree for radial bar icon.
finalinherited
endAngle → double?
Specifies the end angle for radial bar icon.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
iconBorderColor → Color?
Specifies the border of the icon.
finalinherited
iconBorderWidth → double?
Specifies the border width of icon.
finalinherited
iconColor → Color
Specifies the color of the icon.
finalinherited
iconType → ShapeMarkerType
Specifies the type of the icon.
finalinherited
imageProvider → ImageProvider<Object>?
Identifies an image.
finalinherited
isToggled → bool
Specifies whether the current item is toggled.
finalinherited
onRender → ItemRenderCallback?
Invoked when the item is created.
finalinherited
onTap → LegendItemTapCallback?
Invoked when tapping the legend item.
finalinherited
onToggled ↔ VoidCallback?
Specifies the legend item is tapped.
getter/setter pairinherited
overlayMarkerType → ShapeMarkerType?
Specifies the overlay marker for cartesian line type icon.
finalinherited
pointIndex → int
Specifies the index of the data point in the series.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
series → ChartSeriesRenderer?
Specifies the series associated with the legend item.
finalinherited
seriesIndex → int
Specifies the index of the series associated with the legend item.
finalinherited
shader → Shader?
Specifies the shader of the icon.
finalinherited
startAngle → double?
Specifies the start angle for radial bar icon.
finalinherited
text → String
Specifies the text of the legend.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited