CategoricalMultiLevelLabel class

Provides options to customize the start, the end value of a multi-level label, text, and level of the multi-level labels.

The start and end value need to be string type.

Widget build(BuildContext context) {
  return Container(
    child: SfCartesianChart(
      primaryXAxis: CategoryAxis(
        multiLevelLabels: const <CategoricalMultiLevelLabel>[
         CategoricalMultiLevelLabel(start: 'Jan', end: 'Feb', text: 'First')
        ]
      )
    )
  );
}

Constructors

CategoricalMultiLevelLabel({required String start, required String end, int level = 0, String text = ''})
Constructor for CategoricalMultiLevelLabel class.
const

Properties

end → String
End value of the multi-level label. The value where the multi-level label border needs to end.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
level → int
Level specifies in which row the multi-level label should be positioned.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → String
Start value of the multi-level label. The value from where the multi-level label border needs to start.
finalinherited
text → String
Text to be displayed in grouping label as the multi-level label.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited