ChartPointDetails class

Holds the arguments of onPointTap, onPointDoubleTap and onPointLongPress callbacks.

The user can fetch the series index, point index, view port point index and data of the current point.

Constructors

ChartPointDetails([int? seriesIndex, num? viewportPointIndex, List? dataPoints, int? pointIndex])
Creating an argument constructor of ChartPointDetails class.

Properties

dataPoints → List?
Get the list of data points.
final
hashCode → int
The hash code for this object.
no setterinherited
pointIndex → int?
Get the overall index value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seriesIndex → int?
Get the series index.
final
viewportPointIndex → num?
Get the view port index value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited