IndicatorRenderArgs class

Holds the onRenderDetailsUpdate event arguments.

Triggers when indicator is rendering. You can customize the signalLineColor, signalLineWidth, and signalLineDashArray.

Note: This is only applicable for SfCartesianChart.

Annotations
  • @Deprecated('Use IndicatorRenderParams instead.')

Constructors

IndicatorRenderArgs([TechnicalIndicator? indicator, int? index, String? seriesName, List? dataPoints])
Creating an argument constructor of IndicatorRenderArgs class.

Properties

dataPoints → List?
Get the current data points.
final
hashCode → int
The hash code for this object.
no setterinherited
index → int?
Get the current index of the technical indicator.
final
indicator → TechnicalIndicator?
Get the technical indicator information.
final
indicatorName ↔ String
Get the indicator name.
getter/setter pair
lineDashArray ↔ List<double>
Get and set the dash array size.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seriesName → String?
Get the series name.
final
signalLineColor ↔ Color
Get and set the color of the signal line.
getter/setter pair
signalLineWidth ↔ double
Get and set the width of the signal line.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited