IndicatorRenderParams class

Holds the onRenderDetailsUpdate callback arguments.

Implementers

Constructors

IndicatorRenderParams(List<CartesianChartPoint>? calculatedDataPoints, String name, double signalLineWidth, Color signalLineColor, List<double> signalLineDashArray)
Creating an argument constructor of IndicatorRenderParams class.

Properties

calculatedDataPoints → List<CartesianChartPoint>?
Gets the calculated indicator data points details.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Gets the name of the indicator.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signalLineColor ↔ Color
Gets the color of the signal line.
getter/setter pair
signalLineDashArray ↔ List<double>
Gets the dash array of the signal line.
getter/setter pair
signalLineWidth ↔ double
Gets the width of the signal line.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited