PointInfo<D> class

This is similar to the point of the Cartesian chart.

Constructors

PointInfo(dynamic x, num? y)
Creating an argument constructor of PointInfo class.

Properties

borderColor ↔ Color
Stores the border color of point info.
getter/setter pair
borderWidth ↔ num
Stores the border width value.
getter/setter pair
color ↔ Color
Stores the point info color.
getter/setter pair
dataLabelPosition ↔ Position?
Stores the value of label position.
getter/setter pair
dataLabelSize ↔ Size
To check if labels collide. Stores the value data label size.
getter/setter pair
explodeDistance ↔ num?
Stores the value of explode Distance.
getter/setter pair
fill ↔ Color
Fill color of point info.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
heightRatio ↔ num
Stores the value of height ratio.
getter/setter pair
isEmpty ↔ bool
To set the property of empty.
getter/setter pair
isExplode ↔ bool
To set the property of explode.
getter/setter pair
isSelected ↔ bool
To set the property of selection.
getter/setter pair
isShadow ↔ bool
To set the property of shadow.
getter/setter pair
isTooltipRenderEvent ↔ bool
To execute onTooltipRender event or not.
getter/setter pair
isVisible ↔ bool
To set the property of visible.
getter/setter pair
labelRect ↔ Rect?
Stores the value of label rect.
getter/setter pair
labelRenderEvent ↔ bool
To execute OnDataLabelRender event or not.
getter/setter pair
pathRegion ↔ List<Offset>
Stores the list value of path region.
getter/setter pair
region ↔ Rect?
Stores the value of region.
getter/setter pair
renderPosition ↔ ChartDataLabelPosition?
Stores the value of chart data label position.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saturationRegionOutside ↔ bool
To set the saturation region.
getter/setter pair
sortValue ↔ D?
Stores the sort value.
getter/setter pair
symbolLocation ↔ Offset
Stores the offset value of symbol location.
getter/setter pair
text ↔ String?
Text value of point info.
getter/setter pair
x ↔ dynamic
X value of point info.
getter/setter pair
y ↔ num?
Y value of point info.
getter/setter pair
yRatio ↔ num
Stores the value of Y ratio.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited