SelectionArgs class

Holds the onSelectionChanged event arguments.

Here selectedColor, unselectedColor, selectedBorderColor, selectedBorderWidth, unselectedBorderColor and unselectedBorderWidth can be customized.

Constructors

SelectionArgs({required dynamic seriesRenderer, required int seriesIndex, required int viewportPointIndex, required int pointIndex})
Creating an argument constructor of SelectionArgs class.

Properties

hashCode → int
The hash code for this object.
no setterinherited
pointIndex → int
Get the overall index value of the selected data points.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedBorderColor ↔ Color?
Get and set the border color of the selected series or data points.
getter/setter pair
selectedBorderWidth ↔ double?
Get and set the border width of the selected series or data points.
getter/setter pair
selectedColor ↔ Color?
Get and set the color of the selected series or data points.
getter/setter pair
seriesIndex → int
Get the series index.
final
seriesRenderer → dynamic
Get the selected series.
final
unselectedBorderColor ↔ Color?
Get and set the border color of the unselected series or data points.
getter/setter pair
unselectedBorderWidth ↔ double?
Get and set the border width of the unselected series or data points.
getter/setter pair
unselectedColor ↔ Color?
Get and set the color of unselected series or data points.
getter/setter pair
viewportPointIndex → int
Get the view port index value of the selected data points.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited