SfCircularChart class

Renders the circular chart.

The SfCircularChart widget supports pie, doughnut, and radial bar series that can be customized within the circular chart's class.

Widget build(BuildContext context) {
 return Center(
   child:SfCircularChart(
   title: ChartTitle(text: 'Sales by sales person'),
   legend: Legend(isVisible: true),
   series: <PieSeries<_PieData, String>>[
     PieSeries<_PieData, String>(
       explode: true,
       explodeIndex: 0,
       dataSource: pieData,
       xValueMapper: (_PieData data, _) => data.xData,
       yValueMapper: (_PieData data, _) => data.yData,
       dataLabelMapper: (_PieData data, _) => data.text,
       dataLabelSettings: DataLabelSettings(isVisible: true)),
   ]
  )
 );
}

class _PieData {
 _PieData(this.xData, this.yData, [this.text]);
 final String xData;
 final num yData;
 String? text;
}
Inheritance

Constructors

SfCircularChart({Key? key, Color? backgroundColor, ImageProvider<Object>? backgroundImage, List<CircularChartAnnotation>? annotations, Color borderColor = Colors.transparent, double borderWidth = 0.0, CircularLegendRenderCallback? onLegendItemRender, CircularTooltipCallback? onTooltipRender, CircularDataLabelRenderCallback? onDataLabelRender, DataLabelTapCallback? onDataLabelTapped, ChartLegendTapCallback? onLegendTapped, CircularSelectionCallback? onSelectionChanged, CircularTouchInteractionCallback? onChartTouchInteractionUp, CircularTouchInteractionCallback? onChartTouchInteractionDown, CircularTouchInteractionCallback? onChartTouchInteractionMove, CircularShaderCallback? onCreateShader, List<Color>? palette, EdgeInsets margin = const EdgeInsets.fromLTRB(10, 10, 10, 10), List<CircularSeries> series = const <CircularSeries<dynamic, dynamic>>[], ChartTitle title = const ChartTitle(), Legend legend = const Legend(), String centerX = '50%', String centerY = '50%', TooltipBehavior? tooltipBehavior, ActivationMode selectionGesture = ActivationMode.singleTap, bool enableMultiSelection = false})
Creating an argument constructor of SfCircularChart class.
const

Properties

annotations → List<CircularChartAnnotation>?
Customizes the annotations. Annotations are used to mark the specific area of interest in the plot area with texts, shapes, or images.
final
backgroundColor → Color?
Background color of the chart.
final
backgroundImage → ImageProvider<Object>?
Background image for chart.
final
borderColor → Color
Border color of the chart.
final
borderWidth → double
Border width of the chart.
final
centerX → String
X value for placing the chart. The value ranges from 0% to 100% and also if values are mentioned in pixel then the chart will moved accordingly.
final
centerY → String
Y value for placing the chart. The value ranges from 0% to 100% and also if values are mentioned in pixel then the chart will moved accordingly.
final
enableMultiSelection → bool
Enables or disables the multiple data points or series selection.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
legend → Legend
Customizes the legend in the chart.
final
margin → EdgeInsets
Specifies the margin for circular chart.
final
onChartTouchInteractionDown → CircularTouchInteractionCallback?
Occurs when touched on the chart area.
final
onChartTouchInteractionMove → CircularTouchInteractionCallback?
Occurs when touched and moved on the chart area.
final
onChartTouchInteractionUp → CircularTouchInteractionCallback?
Occurs when tapped on the chart area.
final
onCreateShader → CircularShaderCallback?
Fills the data points with the gradient and image shaders.
final
onDataLabelRender → CircularDataLabelRenderCallback?
Occurs while rendering the data label. The data label and text styles such as color, font size, and font weight can be customized. You can get the series index, point index, text, and text style.
final
onDataLabelTapped → DataLabelTapCallback?
Called when the data label is tapped.
final
onLegendItemRender → CircularLegendRenderCallback?
Occurs while legend is rendered. Here, you can get the legend's text, shape, series index, and point index case of circular series.
final
onLegendTapped → ChartLegendTapCallback?
Occurs when the legend is tapped. Here, you can get the series, series index, and point index.
final
onSelectionChanged → CircularSelectionCallback?
Occurs while selection changes. Here, you can get the series, selected color, unselected color, selected border color, unselected border color, selected border width, unselected border width, series index, and point index.
final
onTooltipRender → CircularTooltipCallback?
Occurs while tooltip is rendered. You can customize the position and header. Here, you can get the text, header, point index, series, x and y-positions.
final
palette → List<Color>?
Color palette for the data points in the chart series. If the series color is not specified, then the series will be rendered with appropriate palette color. Ten colors are available by default.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionGesture → ActivationMode
Gesture for activating the selection.
final
series → List<CircularSeries>
Customizes the chart series.
final
title → ChartTitle
Customizes the chart title.
final
tooltipBehavior → TooltipBehavior?
Customizes the tooltip in chart.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited