ShaderDetails class

Holds the onCreateShader callback arguments.

Constructors

ShaderDetails(Rect rect, String renderType)
Creating an argument constructor of ShaderDetails class.

Properties

hashCode → int
The hash code for this object.
no setterinherited
rect → Rect
Holds the chart area rect.
final
renderType → String
Conveys whether the current rendering element is 'series' or 'legend'.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited