SplineRangeAreaSegment<T, D> class

Segment class for spline range area series.

Inheritance

Constructors

SplineRangeAreaSegment()

Properties

animationFactor ↔ double
Animation factor value.
getter/setter pairinherited
currentSegmentIndex ↔ int
Current index value.
getter/setter pairinherited
fillPaint → Paint
Fill paint of the segment.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty ↔ bool
Specifies the segment has empty point.
getter/setter pairinherited
isSelected ↔ bool
getter/setter pairinherited
isVisible ↔ bool
Specifies the segment is visible or not for circular, funnel and pyramid segments only. Not applicable for cartesian segments.
getter/setter pairinherited
points ↔ List<Offset>
Current point offset value.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
series ↔ SplineRangeAreaSeriesRenderer<T, D>
getter/setter pair
strokePaint → Paint
Stroke paint of the segment.
finalinherited

Methods

calculateSegmentPoints() → void
Calculates the rendering bounds of a segment.
override
contains(Offset position) → bool
override
copyOldSegmentValues(double seriesAnimationFactor, double segmentAnimationFactor) → void
override
dispose() → void
To dispose the objects.
override
getFillPaint() → Paint
Gets the color of the series.
override
getStrokePaint() → Paint
Gets the border color of the series.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPaint(Canvas canvas) → void
Draws segment in series bounds.
override
tooltipInfo({Offset? position, int? pointIndex}) → TooltipInfo?
override
toString() → String
A string representation of this object.
inherited
trackballInfo(Offset position, int pointIndex) → TrackballInfo?
override
transformValues() → void
Transforms the x and y values to screen coordinates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited