TooltipArgs class

Holds the arguments for the event onTooltipRender.

Event is triggered when the tooltip is rendered, which allows you to customize tooltip arguments.

Constructors

TooltipArgs([dynamic seriesIndex, List? dataPoints, num? viewportPointIndex, num? pointIndex])
Creating an argument constructor of TooltipArgs class.

Properties

dataPoints → List?
Get the list of data points in the series.
final
hashCode → int
The hash code for this object.
no setterinherited
Get and set the header text of the tooltip.
getter/setter pair
locationX ↔ double?
Get and set the x location of the tooltip.
getter/setter pair
locationY ↔ double?
Get and set the y location of the tooltip.
getter/setter pair
pointIndex → num?
Get the overall index value of the tooltip.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seriesIndex → dynamic
Get the index of the current series.
final
text ↔ String?
Get and set the tooltip text.
getter/setter pair
viewportPointIndex → num?
Get the view port index value of the tooltip.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited