TooltipBehavior class

Customizes the tooltip.

This class provides options for customizing the properties of the tooltip.

Constructors

TooltipBehavior({bool enable = false, TextStyle? textStyle, ActivationMode activationMode = ActivationMode.singleTap, int animationDuration = 350, double opacity = 1.0, Color borderColor = Colors.transparent, double borderWidth = 1, double duration = 3000, bool shouldAlwaysShow = false, double elevation = 2.5, bool canShowMarker = true, ChartAlignment textAlignment = ChartAlignment.center, int decimalPlaces = 3, TooltipPosition tooltipPosition = TooltipPosition.auto, bool shared = false, Color? color, String? header, String? format, ChartWidgetBuilder? builder, Color? shadowColor})
Creating an argument constructor of TooltipBehavior class.

Properties

activationMode → ActivationMode
Gesture for activating the tooltip.
final
animationDuration → int
Duration for animating the tooltip.
final
borderColor → Color
Border color of the tooltip.
final
borderWidth → double
Border width of the tooltip.
final
builder → ChartWidgetBuilder?
Builder of the tooltip.
final
canShowMarker → bool
Toggles the visibility of the marker in the tooltip.
final
color → Color?
Color of the tooltip.
final
decimalPlaces → int
Specifies the number decimals to be displayed in tooltip text.
final
duration → double
Duration for displaying the tooltip.
final
elevation → double
Elevation of the tooltip.
final
enable → bool
Toggles the visibility of the tooltip.
final
format → String?
Formats the tooltip text.
final
hashCode → int
The hash code for this object.
no setterinherited
Header of the tooltip. By default, the series name will be displayed in the header.
final
opacity → double
Opacity of the tooltip.
final
parentBox ↔ RenderBox?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
Color of the tooltip shadow.
final
shared → bool
Share the tooltip with same index points.
final
shouldAlwaysShow → bool
Shows or hides the tooltip.
final
textAlignment → ChartAlignment
Alignment of the text in the tooltip.
final
textStyle → TextStyle?
Customizes the tooltip text.
final
tooltipPosition → TooltipPosition
Show tooltip at tapped position.
final

Methods

handleDoubleTap(Offset position) → void
Called when pointer tap has contacted the screen double time.
inherited
handleEvent(PointerEvent event, BoxHitTestEntry entry) → void
To customize the necessary pointer events in behaviors. (e.g., CrosshairBehavior, TrackballBehavior, ZoomingBehavior).
inherited
handleLongPressEnd(LongPressEndDetails details) → void
Called when the pointer stops contacting the screen after a long-press by a primary button in behavior.
inherited
handleLongPressMoveUpdate(LongPressMoveUpdateDetails details) → void
Called when moving after the long press gesture by a primary button is recognized in behavior.
inherited
handleLongPressStart(LongPressStartDetails details) → void
Called when a long press gesture by a primary button has been recognized in behavior.
inherited
handlePointerEnter(PointerEnterEvent details) → void
Called when a pointer or mouse enter on the screen.
inherited
handlePointerExit(PointerExitEvent details) → void
Called when a pointer or mouse exit on the screen.
inherited
handleScaleEnd(ScaleEndDetails details) → void
Called when the pointers are no longer in contact with the screen.
inherited
handleScaleStart(ScaleStartDetails details) → void
Called when the pointers in contact with the screen and initial scale of 1.0.
inherited
handleScaleUpdate(ScaleUpdateDetails details) → void
Called when the pointers in contact with the screen have indicated a new scale.
inherited
handleTapDown(TapDownDetails details) → void
Called when the pointer tap has contacted the screen in behavior.
inherited
handleTapUp(TapUpDetails details) → void
Called when pointer has stopped contacting screen in behavior.
inherited
hide() → void
Hides the tooltip if it is displayed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPaint(PaintingContext context, Offset offset, SfChartThemeData chartThemeData, ThemeData themeData) → void
Called to customize each behaviors with given context at the given offset.
inherited
show(dynamic x, double y, [String? xAxisName, String? yAxisName]) → void
Displays the tooltip at the specified x and y-values.
showByIndex(int seriesIndex, int pointIndex) → void
Displays the tooltip at the specified series and point index.
showByPixel(double x, double y) → void
Displays the tooltip at the specified x and y-positions.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited