TrackballDetails class

Options to show the details of the trackball template.

Annotations

Constructors

TrackballDetails([CartesianChartPoint? point, dynamic series, int? pointIndex, int? seriesIndex, TrackballGroupingModeInfo? groupingModeInfo])
Constructor of TrackballDetails class.
const

Properties

groupingModeInfo → TrackballGroupingModeInfo?
It specifies the trackball grouping mode info.
final
hashCode → int
The hash code for this object.
no setteroverride
point → CartesianChartPoint?
It specifies the Cartesian chart point.
final
pointIndex → int?
It specifies the point index.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
series → dynamic
It specifies the Cartesian series.
final
seriesIndex → int?
It specifies the series index.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override