TrackballGroupingModeInfo class

Class to store the group mode details of trackball template.

Constructors

TrackballGroupingModeInfo(List<CartesianChartPoint> points, List<int> currentPointIndices, List<int> visibleSeriesIndices, List visibleSeriesList)
Creates an argument constructor for TrackballGroupingModeInfo class.

Properties

currentPointIndices → List<int>
Specifies the current point indices.
final
hashCode → int
The hash code for this object.
no setterinherited
points → List<CartesianChartPoint>
Specifies the cartesian chart points.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visibleSeriesIndices → List<int>
Specifies the visible series indices.
final
visibleSeriesList → List
Specifies the cartesian visible series list.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited