SparkChartLabelDisplayMode enum

Displays the data labels on the spark chart widget in different modes.

Inheritance
Available extensions

Values

none → const SparkChartLabelDisplayMode

SparkChartLabelDisplayMode.none does not allow to display the data label on any data points in the spark chart widget.

all → const SparkChartLabelDisplayMode

SparkChartLabelDisplayMode.none allows to display data label on all the data points in the spark chart widget.

high → const SparkChartLabelDisplayMode

SparkChartLabelDisplayMode.high allows displaying data label only on the highest data points in the spark chart widget.

low → const SparkChartLabelDisplayMode

SparkChartLabelDisplayMode.low allows displaying data label only on the lowest data points in the spark chart widget.

first → const SparkChartLabelDisplayMode

SparkChartLabelDisplayMode.first allows displaying data label only on the first data points in the spark chart widget.

last → const SparkChartLabelDisplayMode

SparkChartLabelDisplayMode.first allows displaying data label only on the last data points in the spark chart widget.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<SparkChartLabelDisplayMode>
A constant List of the values in this enum, in order of their declaration.