TooltipFormatterDetails class

Passes as the argument in the tooltipFormatter callback of trackball. The callback gets triggered when the trackball tooltip label text is created.

Constructors

TooltipFormatterDetails({dynamic x, num? y, String? label})
Creates an instance of TooltipFormatterDetails, where the closest point’s x value and y value and tooltip text is passed as its argument.

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String?
Provides the tooltip label value. By default, the label displays the x and the y value in the format of x : y.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → dynamic
Provides the x value of the closest data point.
final
y → num?
Provides the y value of the closest data point.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited